import com.urbancode.anthill3.AHPTool
import com.urbancode.anthill3.CommandHelper

private void removeViewPrivateFilesFunction(String fileName, File workDirFile, commandPath) {
    if (fileName != null && fileName.trim().length() > 0) {
        File file = new File(workDirFile, fileName)
        if (file.exists()) {
            ByteArrayOutputStream outStream = new ByteArrayOutputStream()
            //------------------------------------------------------------------------------
            // GET THE VIEW PRIVATE FILES FOR THE PATH
            //------------------------------------------------------------------------------

            def cmdArgs = [commandPath, 'ls', '-recurse', '-view_only', '-visible', fileName]
            def comHelp = new CommandHelper(workDirFile)

            ByteArrayOutputStream out = new ByteArrayOutputStream()
            comHelp.runCommand("getting view-private files.", cmdArgs) { proc ->
                proc.out.close() // close stdin
                proc.waitForProcessOutput(out, System.out) // forward stdout and stderr
            }

            // read the output and delete each file
            StringTokenizer tokenizer = new StringTokenizer(out.toString(), "\n\r\f")
            while (tokenizer.hasMoreTokens()) {
                String line = tokenizer.nextToken()
                if (line != null && line.trim().length() > 0) {
                    File fileToDelete = new File(workDirFile, line.trim())
                    if (fileToDelete.exists()) {
                        boolean successfulDelete = false
                        successfulDelete = FileUtils.deleteFileSafely(fileToDelete)
                        if (successfulDelete) {
                            println "Deleted: " + line
                        }
                        else {
                            println "Could not delete: " + line
                        }
                    }
                    else {
                        println "File does not exist: " + fileToDelete.getPath()
                    }
                }
            }
        }
        else {
            println "File for ${fileName} not found"
        }
    }
}

def ch = new CommandHelper(new File('.'))
def ahpTool = new AHPTool()
def props = ahpTool.getStepProperties()

def commandPath = props['source/repo/commandPath']
def removeViewPrivateFiles = props['source/deleteDuringCleanup']
def viewPath = props['source/storageDir']
def vobTagRoot = props['source/tagRoot']
File workDirFile = null
String[] loadRuleTemp = props['source/loadRules'].split('\n')
def loadRuleList = new ArrayList<String[]>()

loadRuleTemp.each { loadRule ->
    int i=0
    String [] tempLoadRuleArray = loadRule.split(':')
    String [] loadRuleArray = new String[4]
    for (i=0; i<tempLoadRuleArray.length && i < 4; i++) {
      loadRuleArray[i] = tempLoadRuleArray[i]
    }
    for (i; i<4; i++ ) {
      loadRuleArray[i] = null
    }
    loadRuleList << loadRuleArray
}


if (viewPath == null || viewPath.trim().length() == 0) {
    throw new IllegalStateException("View path does is not configured")
}

if (commandPath == null || commandPath.trim().length() == 0) {
    commandPath = "cleartool"
}

workDirFile = new File(viewPath)
if (!workDirFile.exists()) {
    throw new IllegalStateException("View path does not exist: " + viewPath)
}

if (loadRuleList == null || loadRuleList.size() == 0) {
    throw new IllegalStateException("No load rules configured")
}

//check if we are to cleanup all viewlocal files
if (removeViewPrivateFiles) {
    loadRuleList.each { loadRule ->
        String vobName = loadRule[0]
        String path = loadRule[1]

        if (path == null || "null".equalsIgnoreCase(path)) {
            path =""
        }
        else {
            path = File.separator + path
        }
        String fileName = vobName+path
        if (ahpTool.isWindows) {
            fileName = vobTagRoot + File.separator + fileName
        }
        println "Removing private files for ${fileName}"
        removeViewPrivateFilesFunction(fileName, workDirFile, commandPath)
    }
}
else {
    println "Nothing to do since Remove View Private Files is set to false!"
}